@@ -41,6 +41,12 @@
 *
 ***********************************************************************/
 
+#ifdef __GCC__
+#define ATTR_UNUSED __attribute__ ((unused)
+#else
+#define ATTR_UNUSED 
+#endif
+
 /* General Definitions */
 
 #define         FLOAT                  float 
