@@ -626,7 +626,7 @@ flump3dec_change_state (GstElement *element, GstStateChange transition)
 }
 
 static const GstQueryType *
-flump3dec_get_query_types (GstPad *pad __attribute__ ((unused)))
+flump3dec_get_query_types (GstPad *pad ATTR_UNUSED)
 {
   static const GstQueryType query_types[] = {
     GST_QUERY_POSITION,
@@ -973,5 +973,4 @@ GST_PLUGIN_DEFINE (GST_VERSION_MAJOR, GST_VERSION_MINOR,
   "flump3dec", "Fluendo MP3 decoder",
   plugin_init, VERSION, GST_LICENSE_UNKNOWN, "Fluendo MP3 Decoder",
   "http://www.fluendo.com"
-);
-
+)
