@@ -20,7 +20,7 @@
 #define HTSIZE  34
 #define MXOFF   250
 
-const HUFFBITS dmask = 1 << (sizeof (HUFFBITS) * 8 - 1);
+const HUFFBITS dmask = (guint32)(1) << (sizeof (HUFFBITS) * 8 - 1);
 const guint hs = sizeof (HUFFBITS) * 8;
 
 /* do the huffman-decoding 						*/
