@@ -130,6 +130,7 @@ III_get_side_info (Bit_stream_struc *bs, III_side_info_t *si,
           gi->block_type = 0;
         }
 
+        gi->preflag = 0;
         gi->scalefac_scale = bs_get1bit (bs);
         gi->count1table_select = bs_get1bit (bs);
       }
@@ -1342,7 +1343,7 @@ III_hybrid (gfloat fsIn[SSLIMIT], gfloat tsOut[SSLIMIT], int sb, int ch,
  * filtering */
 static void
 III_frequency_inversion (gfloat hybridOut[SBLIMIT][SSLIMIT], 
-    mp3tl *tl __attribute__ ((unused)))
+    mp3tl *tl ATTR_UNUSED)
 {
   guint ss, sb;
 
@@ -1525,7 +1526,7 @@ void mp3_flush (mp3tl *tl)
   init_hybrid (&tl->c_impl);  
 }
 
-void mp3_close (mp3tl *tl __attribute__ ((unused)))
+void mp3_close (mp3tl *tl ATTR_UNUSED)
 {
 }
 
