@@ -12,8 +12,6 @@
 typedef struct mp3cimpl_info mp3cimpl_info;
 
 struct mp3cimpl_info {
-  gint  frame_start;
-
   huffdec_bitbuf bb;          /* huffman decoder bit buffer */
 
   /* Hybrid */
@@ -23,4 +21,8 @@ struct mp3cimpl_info {
   guint scalefac_buffer[54];
 };
 
+void III_subband_synthesis (mp3tl *tl, frame_params *fr_ps, 
+   gfloat hybridOut[SBLIMIT][SSLIMIT], gint channel, 
+   short samples[SSLIMIT][SBLIMIT]);
+
 #endif
