@@ -83,6 +83,6 @@ Mp3TlRetcode decode_mp3 (mp3tl *tl);
 gboolean mp3_init (mp3tl *tl);
 void mp3_flush (mp3tl *tl);
 void mp3_close (mp3tl *tl);
-void mp3_SubBandSynthesis (mp3tl *tl __attribute__ ((unused)), 
+void mp3_SubBandSynthesis (mp3tl *tl ATTR_UNUSED,
     frame_params *fr_ps, float *bandPtr, gint channel, short *samples);
 #endif
